--- /dev/null
+++ transmission-3.00-libkcapi/cmake/FindKCAPI.cmake
@@ -0,0 +1,6 @@
+
+find_path(KCAPI_INCLUDE_DIR kcapi.h)
+find_library(KCAPI_LIBRARY NAMES kcapi libkcapi)
+
+set(KCAPI_INCLUDE_DIRS ${KCAPI_INCLUDE_DIR})
+set(KCAPI_LIBRARIES ${KCAPI_LIBRARY})
--- transmission-3.00/libtransmission/CMakeLists.txt
+++ transmission-3.00-libkcapi/libtransmission/CMakeLists.txt
@@ -274,6 +274,7 @@
     ${LIBINTL_LIBRARY}
     ${LIBM_LIBRARY}
     ${TR_NETWORK_LIBRARIES}
+    ${KCAPI_LIBRARIES}
 )

 if(ICONV_FOUND)
--- transmission-3.00/CMakeLists.txt
+++ transmission-3.00-libkcapi/libtransmission/CMakeLists.txt
@@ -141,6 +141,7 @@
 if(WITH_CRYPTO STREQUAL "AUTO" OR WITH_CRYPTO STREQUAL "openssl")
     tr_get_required_flag(WITH_CRYPTO OPENSSL_IS_REQUIRED)
     find_package(OpenSSL ${OPENSSL_MINIMUM} ${OPENSSL_IS_REQUIRED})
+    find_package(KCAPI 1.2.1 REQUIRED)
     tr_fixup_list_option(WITH_CRYPTO "openssl" OPENSSL_FOUND "AUTO" OPENSSL_IS_REQUIRED)
     if(WITH_CRYPTO STREQUAL "openssl")
         set(CRYPTO_PKG "openssl")
--- transmission-3.00/libtransmission/crypto-utils-openssl.c
+++ transmission-3.00-libkcapi/libtransmission/crypto-utils-openssl.c
@@ -27,6 +27,8 @@
 #include "tr-assert.h"
 #include "utils.h"
 
+#include "kcapi.h"
+
 #define TR_CRYPTO_DH_SECRET_FALLBACK
 #include "crypto-utils-fallback.c"
 
@@ -104,15 +106,12 @@
 
 tr_sha1_ctx_t tr_sha1_init(void)
 {
-    EVP_MD_CTX* handle = EVP_MD_CTX_create();
+    struct kcapi_handle *handle;
 
-    if (check_result(EVP_DigestInit_ex(handle, EVP_sha1(), NULL)))
-    {
-        return handle;
-    }
+    kcapi_md_init(&handle, "sha1", 0);
+    return handle;
 
-    EVP_MD_CTX_destroy(handle);
-    return NULL;
+    kcapi_md_destroy(handle);
 }
 
 bool tr_sha1_update(tr_sha1_ctx_t handle, void const* data, size_t data_length)
@@ -126,26 +125,23 @@
 
     TR_ASSERT(data != NULL);
 
-    return check_result(EVP_DigestUpdate(handle, data, data_length));
+    kcapi_md_update(handle, data, data_length);
+    return true;
 }
 
 bool tr_sha1_final(tr_sha1_ctx_t handle, uint8_t* hash)
 {
-    bool ret = true;
-
     if (hash != NULL)
     {
         TR_ASSERT(handle != NULL);
 
-        unsigned int hash_length;
+        uint32_t hash_length = 20;
+        kcapi_md_final(handle, hash, hash_length);
 
-        ret = check_result(EVP_DigestFinal_ex(handle, hash, &hash_length));
-
-        TR_ASSERT(!ret || hash_length == SHA_DIGEST_LENGTH);
     }
 
-    EVP_MD_CTX_destroy(handle);
-    return ret;
+    kcapi_md_destroy(handle);
+    return true;
 }
 
 /***
--- transmission-3.00/libtransmission/verify.c
+++ transmission-3.00-libkcapi/libtransmission/verify.c
@@ -27,7 +27,7 @@
 
 enum
 {
-    MSEC_TO_SLEEP_PER_SECOND_DURING_VERIFY = 100
+    MSEC_TO_SLEEP_PER_SECOND_DURING_VERIFY = 10
 };
 
 static bool verifyTorrent(tr_torrent* tor, bool* stopFlag)
@@ -44,7 +44,7 @@
     tr_file_index_t prevFileIndex = !fileIndex;
     tr_piece_index_t pieceIndex = 0;
     time_t const begin = tr_time();
-    size_t const buflen = 1024 * 128; /* 128 KiB buffer */
+    size_t const buflen = 1024 * 512; /* 512 KiB buffer - orig 128 */
     uint8_t* buffer = tr_valloc(buflen);
 
     sha = tr_sha1_init();
